"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addBaseSelector = addBaseSelector;
exports.default = _default;

var _transformThemeValue = _interopRequireDefault(require("../util/transformThemeValue"));

var _postcss = _interopRequireDefault(require("postcss"));

var _parseObjectStyles = _interopRequireDefault(require("../util/parseObjectStyles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let baseRulesKey = Symbol();

function addBaseSelector(memory, selector) {
  let baseRoot = memory.get(baseRulesKey);

  if (baseRoot.nodes.length === 0) {
    baseRoot.append((0, _parseObjectStyles.default)({
      [selector]: {
        '--tw-ring-offset-shadow': '0 0 #0000',
        '--tw-ring-shadow': '0 0 #0000',
        '--tw-shadow': '0 0 #0000'
      }
    }));
  } else {
    baseRoot.nodes[0].selectors = [...baseRoot.nodes[0].selectors, selector];
  }
}

let transformValue = (0, _transformThemeValue.default)('boxShadow');
let defaultBoxShadow = [`var(--tw-ring-offset-shadow, 0 0 #0000)`, `var(--tw-ring-shadow, 0 0 #0000)`, `var(--tw-shadow)`].join(', ');

function _default() {
  return function ({
    config,
    matchUtilities,
    addBase,
    addUtilities,
    theme,
    variants,
    memory
  }) {
    if (config('mode') === 'jit') {
      let baseRoot = _postcss.default.root();

      memory.set(baseRulesKey, baseRoot);
      addBase(baseRoot);
    } else {
      addUtilities({
        '*, ::before, ::after': {
          '--tw-shadow': '0 0 #0000'
        }
      }, {
        respectImportant: false
      });
    }

    matchUtilities({
      shadow: (value, {
        selector
      }) => {
        if (config('mode') === 'jit') {
          addBaseSelector(memory, selector);
        }

        value = transformValue(value);
        return {
          '--tw-shadow': value === 'none' ? '0 0 #0000' : value,
          'box-shadow': defaultBoxShadow
        };
      }
    }, {
      values: theme('boxShadow'),
      variants: variants('boxShadow'),
      type: 'lookup'
    });
  };
}