"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addBaseSelector = addBaseSelector;
exports.default = _default;

var _postcss = _interopRequireDefault(require("postcss"));

var _parseObjectStyles = _interopRequireDefault(require("../util/parseObjectStyles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let baseRulesKey = Symbol();

function addBaseSelector(memory, selector) {
  let baseRoot = memory.get(baseRulesKey);

  if (baseRoot.nodes.length === 0) {
    baseRoot.append((0, _parseObjectStyles.default)({
      [selector]: {
        '--tw-translate-x': '0',
        '--tw-translate-y': '0',
        '--tw-rotate': '0',
        '--tw-skew-x': '0',
        '--tw-skew-y': '0',
        '--tw-scale-x': '1',
        '--tw-scale-y': '1',
        '--tw-transform': ['translateX(var(--tw-translate-x))', 'translateY(var(--tw-translate-y))', 'rotate(var(--tw-rotate))', 'skewX(var(--tw-skew-x))', 'skewY(var(--tw-skew-y))', 'scaleX(var(--tw-scale-x))', 'scaleY(var(--tw-scale-y))'].join(' ')
      }
    }));
  } else {
    baseRoot.nodes[0].selectors = [...baseRoot.nodes[0].selectors, selector];
  }
}

function _default() {
  return function ({
    config,
    matchUtilities,
    addBase,
    addUtilities,
    variants,
    memory
  }) {
    if (config('mode') === 'jit') {
      let baseRoot = _postcss.default.root();

      memory.set(baseRulesKey, baseRoot);
      addBase(baseRoot);
      matchUtilities({
        transform: (value, {
          selector
        }) => {
          if (value !== 'none') {
            addBaseSelector(memory, selector);
          }

          return {
            transform: value
          };
        }
      }, {
        values: {
          DEFAULT: 'var(--tw-transform)',
          cpu: ['translateX(var(--tw-translate-x))', 'translateY(var(--tw-translate-y))', 'rotate(var(--tw-rotate))', 'skewX(var(--tw-skew-x))', 'skewY(var(--tw-skew-y))', 'scaleX(var(--tw-scale-x))', 'scaleY(var(--tw-scale-y))'].join(' '),
          gpu: ['translate3d(var(--tw-translate-x), var(--tw-translate-y), 0)', 'rotate(var(--tw-rotate))', 'skewX(var(--tw-skew-x))', 'skewY(var(--tw-skew-y))', 'scaleX(var(--tw-scale-x))', 'scaleY(var(--tw-scale-y))'].join(' '),
          none: 'none'
        },
        variants: variants('transform'),
        type: 'any'
      });
    } else {
      addUtilities({
        '.transform': {
          '--tw-translate-x': '0',
          '--tw-translate-y': '0',
          '--tw-rotate': '0',
          '--tw-skew-x': '0',
          '--tw-skew-y': '0',
          '--tw-scale-x': '1',
          '--tw-scale-y': '1',
          transform: ['translateX(var(--tw-translate-x))', 'translateY(var(--tw-translate-y))', 'rotate(var(--tw-rotate))', 'skewX(var(--tw-skew-x))', 'skewY(var(--tw-skew-y))', 'scaleX(var(--tw-scale-x))', 'scaleY(var(--tw-scale-y))'].join(' ')
        },
        '.transform-gpu': {
          '--tw-translate-x': '0',
          '--tw-translate-y': '0',
          '--tw-rotate': '0',
          '--tw-skew-x': '0',
          '--tw-skew-y': '0',
          '--tw-scale-x': '1',
          '--tw-scale-y': '1',
          transform: ['translate3d(var(--tw-translate-x), var(--tw-translate-y), 0)', 'rotate(var(--tw-rotate))', 'skewX(var(--tw-skew-x))', 'skewY(var(--tw-skew-y))', 'scaleX(var(--tw-scale-x))', 'scaleY(var(--tw-scale-y))'].join(' ')
        },
        '.transform-none': {
          transform: 'none'
        }
      }, variants('transform'));
    }
  };
}